You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@reef.apache.org by ma...@apache.org on 2015/10/14 20:57:45 UTC

[2/2] incubator-reef git commit: [REEF-839] Fix typos in REEF.NET

[REEF-839] Fix typos in REEF.NET

This fixes many typos in C# files.

JIRA:
  [REEF-839](https://issues.apache.org/jira/browse/REEF-839)

Pull Request:
  This closes #561


Project: http://git-wip-us.apache.org/repos/asf/incubator-reef/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-reef/commit/8b7189bd
Tree: http://git-wip-us.apache.org/repos/asf/incubator-reef/tree/8b7189bd
Diff: http://git-wip-us.apache.org/repos/asf/incubator-reef/diff/8b7189bd

Branch: refs/heads/master
Commit: 8b7189bd764cea5421d4810fd5b024b935e3e67c
Parents: e9a17d5
Author: Dongjoon Hyun <do...@apache.org>
Authored: Tue Oct 13 09:49:41 2015 +0900
Committer: Mariia Mykhailova <ma...@apache.org>
Committed: Wed Oct 14 11:56:22 2015 -0700

----------------------------------------------------------------------
 .../TestHttpSerialization.cs                    | 18 ++--
 .../Avro/AvroHttpSerializer.cs                  | 25 ++++--
 .../Avro/AvroJsonSerializer.cs                  |  2 +-
 .../Protobuf/ReefProtocol/Serializer.cs         |  2 +-
 .../Evaluator/ReefMessageProtoObserver.cs       |  2 +-
 .../Runtime/Evaluator/Task/DriverMessageImpl.cs |  2 +-
 .../Runtime/Evaluator/Task/TaskStatus.cs        |  2 +-
 .../Evaluator/Utils/EvaluatorConfigurations.cs  |  2 +-
 .../Bridge/ClrHandlerHelper.cs                  |  4 +-
 .../Bridge/DriverBridge.cs                      |  4 +-
 .../Bridge/HttpServerHandler.cs                 |  2 +-
 lang/cs/Org.Apache.REEF.Driver/Constants.cs     |  9 +-
 .../DefaultClientCloseWithMessageHandler.cs     |  2 +-
 .../Defaults/DefaultClientMessageHandler.cs     |  2 +-
 .../Defaults/DefaultContextMessageHandler.cs    |  4 +-
 .../DefaultEvaluatorRequestorHandler.cs         |  2 +-
 .../Defaults/DefaultHttpHandler.cs              |  2 +-
 .../DriverConfigGenerator.cs                    | 14 +--
 .../DriverConfiguration.cs                      |  6 +-
 .../DriverConfigurationSettings.cs              |  8 +-
 .../DriverSubmissionSettings.cs                 |  7 ++
 .../EvaluatorConfigurationsTests.cs             |  2 +-
 .../EvaluatorTests.cs                           |  4 +-
 lang/cs/Org.Apache.REEF.Evaluator/Evaluator.cs  | 16 ++--
 .../AllHandlers.cs                              |  4 +-
 .../HelloFailedTaskHandler.cs                   |  2 +-
 .../HelloHttpHandler.cs                         |  7 +-
 .../HelloTaskCompletedHandler.cs                |  2 +-
 .../DriverRestart/HelloRestartTask.cs           |  2 +-
 .../MachineLearning/KMeans/Centroids.cs         |  2 +-
 .../MachineLearning/KMeans/ProcessedResults.cs  |  2 +-
 .../KMeans/codecs/ProcessedResultsCodec.cs      |  4 +-
 .../Tasks/HelloTask/HelloTask.cs                |  2 +-
 .../HadoopFileSystemConfigurationProvider.cs    |  2 +-
 .../BroadcastAndReduceClient.cs                 |  4 +-
 .../PipelinedBroadcastReduceDriver.cs           |  2 +-
 .../GroupCommunicationTests.cs                  | 30 +++----
 .../Group/Config/CodecConfiguration.cs          |  2 +-
 .../Group/Driver/ICommunicationGroupDriver.cs   |  4 +-
 .../Group/Operators/IOperatorSpec.cs            |  7 +-
 .../Operators/Impl/BroadcastOperatorSpec.cs     | 15 +++-
 .../Group/Operators/Impl/ReduceOperatorSpec.cs  | 14 ++-
 .../Group/Operators/Impl/ScatterOperatorSpec.cs | 16 +++-
 .../Task/ICommunicationGroupClientInternal.cs   |  2 +-
 .../Group/Task/Impl/CommunicationGroupClient.cs |  2 +-
 .../Group/Topology/FlatTopology.cs              |  2 +-
 .../Group/Topology/TreeTopology.cs              |  4 +-
 .../Naming/NameClient.cs                        |  2 +-
 .../Naming/NameLookupClient.cs                  |  2 +-
 .../Naming/NameRegisterClient.cs                |  2 +-
 .../ClassHierarchy/TestAvroSerialization.cs     | 40 ++++-----
 .../Configuration/TestConfiguration.cs          | 16 ++--
 .../Format/TestConfigurationModule.cs           |  2 +-
 .../ScenarioTest/HttpHandlerConfiguration.cs    |  2 +-
 .../ScenarioTest/JettyHandler.cs                |  6 +-
 .../ScenarioTest/TestDefaultConstructor.cs      |  2 +-
 .../ScenarioTest/TestHttpService.cs             |  6 +-
 .../ScenarioTest/TestRuntimeClock.cs            |  6 +-
 .../SmokeTest/ObjectTreeTest.cs                 |  2 +-
 .../SmokeTest/RootImplementation.cs             |  2 +-
 .../SmokeTest/TestConfigurationModuleBuilder.cs |  2 +-
 .../Tang/TestDefaultImpementaion.cs             |  4 +-
 .../Formats/AvroConfigurationSerializer.cs      | 27 +++---
 .../Formats/ConfigurationFile.cs                | 90 ++------------------
 .../Formats/IConfigurationSerializer.cs         |  2 +-
 .../AvroClassHierarchySerializer.cs             | 18 ++--
 .../ClassHierarchy/ClassHierarchyImpl.cs        |  2 +-
 .../Configuration/CsConfigurationBuilderImpl.cs |  8 +-
 .../InjectionPlan/InjectorImpl.cs               |  4 +-
 .../Implementations/InjectionPlan/Subplan.cs    |  2 +-
 .../Implementations/Tang/TangImpl.cs            |  4 +-
 .../Interface/IClassHierarchySerializer.cs      | 12 +--
 .../Util/ReflectionUtilities.cs                 | 13 ++-
 .../Bridge/HelloSimpleEventHandlers.cs          |  4 +-
 .../Functional/ML/KMeans/TestKMeans.cs          |  2 +-
 .../Functional/Messaging/MessageDriver.cs       |  6 +-
 .../Functional/Messaging/MessageTask.cs         |  6 +-
 .../Functional/ReefFunctionalTest.cs            | 12 +--
 .../Org.Apache.REEF.Utilities/ByteUtilities.cs  |  7 ++
 .../Diagnostics/Exceptions.cs                   |  8 +-
 .../Org.Apache.REEF.Utilities/Logging/Logger.cs |  7 ++
 lang/cs/Org.Apache.REEF.Wake.Tests/ClockTest.cs |  2 +-
 .../Examples/P2p/Pull2Push.cs                   |  2 +-
 .../Remote/Impl/MultiCodec.cs                   |  2 +-
 .../Remote/Impl/StreamingTransportServer.cs     |  8 +-
 .../Remote/Impl/TransportServer.cs              |  6 +-
 86 files changed, 319 insertions(+), 307 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-reef/blob/8b7189bd/lang/cs/Org.Apache.REEF.Common.Tests/TestHttpSerialization.cs
----------------------------------------------------------------------
diff --git a/lang/cs/Org.Apache.REEF.Common.Tests/TestHttpSerialization.cs b/lang/cs/Org.Apache.REEF.Common.Tests/TestHttpSerialization.cs
index de2cffd..10a6d8c 100644
--- a/lang/cs/Org.Apache.REEF.Common.Tests/TestHttpSerialization.cs
+++ b/lang/cs/Org.Apache.REEF.Common.Tests/TestHttpSerialization.cs
@@ -39,14 +39,14 @@ namespace Org.Apache.REEF.Common.Tests
         [TestMethod]
         public void TestHttpRequestSerializationJasonRoundTrip()
         {
-            AvroHttpRequest r = CreatAvorHttpRequest();
+            AvroHttpRequest r = CreateAvroHttpRequest();
 
             string str = AvroHttpSerializer.ToJson(r);
             byte[] bytes = ByteUtilities.StringToByteArrays(str);
-            var r1 = AvroHttpSerializer.FromBytesWithJoson(bytes);
+            var r1 = AvroHttpSerializer.FromBytesWithJson(bytes);
 
-            var ri = ByteUtilities.ByteArrarysToString(r.InputStream);
-            var ri1 = ByteUtilities.ByteArrarysToString(r1.InputStream);
+            var ri = ByteUtilities.ByteArraysToString(r.InputStream);
+            var ri1 = ByteUtilities.ByteArraysToString(r1.InputStream);
             Assert.AreEqual(ri, ri1);
             Assert.AreEqual(r.QueryString, r1.QueryString);
         }
@@ -57,22 +57,22 @@ namespace Org.Apache.REEF.Common.Tests
         [TestMethod]
         public void TestHttpRequestSerializationBytesRoundTrip()
         {
-            AvroHttpRequest r = CreatAvorHttpRequest();
+            AvroHttpRequest r = CreateAvroHttpRequest();
 
             var b = AvroHttpSerializer.ToBytes(r);
             var r1 = AvroHttpSerializer.FromBytes(b);
 
-            var ri = ByteUtilities.ByteArrarysToString(r.InputStream);
-            var ri1 = ByteUtilities.ByteArrarysToString(r1.InputStream);
+            var ri = ByteUtilities.ByteArraysToString(r.InputStream);
+            var ri1 = ByteUtilities.ByteArraysToString(r1.InputStream);
             Assert.AreEqual(ri, ri1);
             Assert.AreEqual(r.QueryString, r1.QueryString);
         }
 
         /// <summary>
-        /// Creats an Avor HTTP request for unit tests.
+        /// Creates an Avro HTTP request for unit tests.
         /// </summary>
         /// <returns>AvroHttpRequest.</returns>
-        private AvroHttpRequest CreatAvorHttpRequest()
+        private AvroHttpRequest CreateAvroHttpRequest()
         {
             AvroHttpRequest r = new AvroHttpRequest();
             r.Header = new List<HeaderEntry>();

http://git-wip-us.apache.org/repos/asf/incubator-reef/blob/8b7189bd/lang/cs/Org.Apache.REEF.Common/Avro/AvroHttpSerializer.cs
----------------------------------------------------------------------
diff --git a/lang/cs/Org.Apache.REEF.Common/Avro/AvroHttpSerializer.cs b/lang/cs/Org.Apache.REEF.Common/Avro/AvroHttpSerializer.cs
index 6b936f7..24d9628 100644
--- a/lang/cs/Org.Apache.REEF.Common/Avro/AvroHttpSerializer.cs
+++ b/lang/cs/Org.Apache.REEF.Common/Avro/AvroHttpSerializer.cs
@@ -17,6 +17,7 @@
  * under the License.
  */
 
+using System;
 using System.IO;
 using Microsoft.Hadoop.Avro;
 using Newtonsoft.Json;
@@ -27,6 +28,7 @@ namespace Org.Apache.REEF.Common.Avro
     /// <summary>
     /// Class AvroHttpSerializer. Provides methods to serialize and deserialize HttpRequest
     /// </summary>
+    // TODO[REEF-842] Act on the obsoletes
     public class AvroHttpSerializer
     {
         public static AvroHttpRequest FromBytes(byte[] serializedBytes)
@@ -39,24 +41,35 @@ namespace Org.Apache.REEF.Common.Avro
         }
 
         /// <summary>
-        /// Conver bytes which contains Json string into AvroHttpRequest object
+        /// Convert bytes which contains Json string into AvroHttpRequest object
         /// </summary>
         /// <param name="serializedBytes">The serialized bytes.</param>
         /// <returns>AvroHttpRequest.</returns>
+        [Obsolete("Deprecated in 0.14, please use FromBytesWithJson instead.")]
         public static AvroHttpRequest FromBytesWithJoson(byte[] serializedBytes)
         {
-            string s = ByteUtilities.ByteArrarysToString(serializedBytes);
+            return FromBytesWithJson(serializedBytes);
+        }
+
+        /// <summary>
+        /// Convert bytes which contains Json string into AvroHttpRequest object
+        /// </summary>
+        /// <param name="serializedBytes">The serialized bytes.</param>
+        /// <returns>AvroHttpRequest.</returns>
+        public static AvroHttpRequest FromBytesWithJson(byte[] serializedBytes)
+        {
+            string s = ByteUtilities.ByteArraysToString(serializedBytes);
             return FromJson(s);
         }
 
         /// <summary>
         /// Convert from Json string into AvroHttpRequest object
         /// </summary>
-        /// <param name="josonString">The joson string.</param>
+        /// <param name="jsonString">The json string.</param>
         /// <returns>AvroHttpRequest.</returns>
-        public static AvroHttpRequest FromJson(string josonString)
+        public static AvroHttpRequest FromJson(string jsonString)
         {
-           return JsonConvert.DeserializeObject<AvroHttpRequest>(josonString);
+           return JsonConvert.DeserializeObject<AvroHttpRequest>(jsonString);
         }
 
         /// <summary>
@@ -110,4 +123,4 @@ namespace Org.Apache.REEF.Common.Avro
             }
         }
     }
-}
\ No newline at end of file
+}

http://git-wip-us.apache.org/repos/asf/incubator-reef/blob/8b7189bd/lang/cs/Org.Apache.REEF.Common/Avro/AvroJsonSerializer.cs
----------------------------------------------------------------------
diff --git a/lang/cs/Org.Apache.REEF.Common/Avro/AvroJsonSerializer.cs b/lang/cs/Org.Apache.REEF.Common/Avro/AvroJsonSerializer.cs
index 8954fe9..4a86177 100644
--- a/lang/cs/Org.Apache.REEF.Common/Avro/AvroJsonSerializer.cs
+++ b/lang/cs/Org.Apache.REEF.Common/Avro/AvroJsonSerializer.cs
@@ -40,7 +40,7 @@ namespace Org.Apache.REEF.Common.Avro
 
         public static T FromBytes(byte[] bytes)
         {
-            return FromString(ByteUtilities.ByteArrarysToString(bytes));
+            return FromString(ByteUtilities.ByteArraysToString(bytes));
         }
 
         public static byte[] ToBytes(T obj)

http://git-wip-us.apache.org/repos/asf/incubator-reef/blob/8b7189bd/lang/cs/Org.Apache.REEF.Common/Protobuf/ReefProtocol/Serializer.cs
----------------------------------------------------------------------
diff --git a/lang/cs/Org.Apache.REEF.Common/Protobuf/ReefProtocol/Serializer.cs b/lang/cs/Org.Apache.REEF.Common/Protobuf/ReefProtocol/Serializer.cs
index 093d0d3..152fe5c 100644
--- a/lang/cs/Org.Apache.REEF.Common/Protobuf/ReefProtocol/Serializer.cs
+++ b/lang/cs/Org.Apache.REEF.Common/Protobuf/ReefProtocol/Serializer.cs
@@ -107,7 +107,7 @@ namespace Org.Apache.REEF.Common.Protobuf.ReefProtocol
             {
                 foreach (TaskStatusProto.TaskMessageProto taskMessageProto in task_status.task_message)
                 {
-                    taskStatusMessage += ByteUtilities.ByteArrarysToString(taskMessageProto.message);
+                    taskStatusMessage += ByteUtilities.ByteArraysToString(taskMessageProto.message);
                 }
             }
             return string.Format(CultureInfo.InvariantCulture, "EvaluatorHeartbeatProto: task_id=[{0}], task_status=[{1}], task_message=[{2}], evaluator_status=[{3}], context_status=[{4}], timestamp=[{5}], recoveryFlag =[{6}]",

http://git-wip-us.apache.org/repos/asf/incubator-reef/blob/8b7189bd/lang/cs/Org.Apache.REEF.Common/Runtime/Evaluator/ReefMessageProtoObserver.cs
----------------------------------------------------------------------
diff --git a/lang/cs/Org.Apache.REEF.Common/Runtime/Evaluator/ReefMessageProtoObserver.cs b/lang/cs/Org.Apache.REEF.Common/Runtime/Evaluator/ReefMessageProtoObserver.cs
index d1a9f8d..66e925c 100644
--- a/lang/cs/Org.Apache.REEF.Common/Runtime/Evaluator/ReefMessageProtoObserver.cs
+++ b/lang/cs/Org.Apache.REEF.Common/Runtime/Evaluator/ReefMessageProtoObserver.cs
@@ -65,7 +65,7 @@ namespace Org.Apache.REEF.Common.Runtime.Evaluator
                     }
                     if (remoteEvent.evaluatorControl.context_control.task_message != null)
                     {
-                        task_message = ByteUtilities.ByteArrarysToString(remoteEvent.evaluatorControl.context_control.task_message);
+                        task_message = ByteUtilities.ByteArraysToString(remoteEvent.evaluatorControl.context_control.task_message);
                     }
 
                     if (!(string.IsNullOrEmpty(context_message) && string.IsNullOrEmpty(task_message)))

http://git-wip-us.apache.org/repos/asf/incubator-reef/blob/8b7189bd/lang/cs/Org.Apache.REEF.Common/Runtime/Evaluator/Task/DriverMessageImpl.cs
----------------------------------------------------------------------
diff --git a/lang/cs/Org.Apache.REEF.Common/Runtime/Evaluator/Task/DriverMessageImpl.cs b/lang/cs/Org.Apache.REEF.Common/Runtime/Evaluator/Task/DriverMessageImpl.cs
index d01d52a..a2377de 100644
--- a/lang/cs/Org.Apache.REEF.Common/Runtime/Evaluator/Task/DriverMessageImpl.cs
+++ b/lang/cs/Org.Apache.REEF.Common/Runtime/Evaluator/Task/DriverMessageImpl.cs
@@ -46,7 +46,7 @@ namespace Org.Apache.REEF.Common.Runtime.Evaluator.Task
 
         public override string ToString()
         {
-            return "DriverMessage [value=" + ByteUtilities.ByteArrarysToString(_value.Value) + "]";
+            return "DriverMessage [value=" + ByteUtilities.ByteArraysToString(_value.Value) + "]";
         }
     }
 }

http://git-wip-us.apache.org/repos/asf/incubator-reef/blob/8b7189bd/lang/cs/Org.Apache.REEF.Common/Runtime/Evaluator/Task/TaskStatus.cs
----------------------------------------------------------------------
diff --git a/lang/cs/Org.Apache.REEF.Common/Runtime/Evaluator/Task/TaskStatus.cs b/lang/cs/Org.Apache.REEF.Common/Runtime/Evaluator/Task/TaskStatus.cs
index bdf9af8..5b1c4dc 100644
--- a/lang/cs/Org.Apache.REEF.Common/Runtime/Evaluator/Task/TaskStatus.cs
+++ b/lang/cs/Org.Apache.REEF.Common/Runtime/Evaluator/Task/TaskStatus.cs
@@ -274,7 +274,7 @@ namespace Org.Apache.REEF.Common.Runtime.Evaluator.Task
         {
             if (_result.IsPresent() && _lastException.IsPresent())
             {
-                LOGGER.Log(Level.Warning, "Both task result and exception are present, the expcetion will take over. Thrown away result:" + ByteUtilities.ByteArrarysToString(_result.Value));
+                LOGGER.Log(Level.Warning, "Both task result and exception are present, the expcetion will take over. Thrown away result:" + ByteUtilities.ByteArraysToString(_result.Value));
                 State = TaskState.Failed;
                 _result = Optional<byte[]>.Empty();
             }

http://git-wip-us.apache.org/repos/asf/incubator-reef/blob/8b7189bd/lang/cs/Org.Apache.REEF.Common/Runtime/Evaluator/Utils/EvaluatorConfigurations.cs
----------------------------------------------------------------------
diff --git a/lang/cs/Org.Apache.REEF.Common/Runtime/Evaluator/Utils/EvaluatorConfigurations.cs b/lang/cs/Org.Apache.REEF.Common/Runtime/Evaluator/Utils/EvaluatorConfigurations.cs
index a54a508..1711475 100644
--- a/lang/cs/Org.Apache.REEF.Common/Runtime/Evaluator/Utils/EvaluatorConfigurations.cs
+++ b/lang/cs/Org.Apache.REEF.Common/Runtime/Evaluator/Utils/EvaluatorConfigurations.cs
@@ -64,7 +64,7 @@ namespace Org.Apache.REEF.Common.Runtime.Evaluator.Utils
                 }
                 _configFile = configFile;
                 AvroConfigurationSerializer serializer = new AvroConfigurationSerializer();
-                _avroConfiguration = serializer.AvroDeseriaizeFromFile(_configFile);
+                _avroConfiguration = serializer.AvroDeserializeFromFile(_configFile);
             }
         }
 

http://git-wip-us.apache.org/repos/asf/incubator-reef/blob/8b7189bd/lang/cs/Org.Apache.REEF.Driver/Bridge/ClrHandlerHelper.cs
----------------------------------------------------------------------
diff --git a/lang/cs/Org.Apache.REEF.Driver/Bridge/ClrHandlerHelper.cs b/lang/cs/Org.Apache.REEF.Driver/Bridge/ClrHandlerHelper.cs
index a13a445..7b07ce0 100644
--- a/lang/cs/Org.Apache.REEF.Driver/Bridge/ClrHandlerHelper.cs
+++ b/lang/cs/Org.Apache.REEF.Driver/Bridge/ClrHandlerHelper.cs
@@ -107,9 +107,9 @@ namespace Org.Apache.REEF.Driver.Bridge
             using (LOGGER.LogFunction("ClrHandlerHelper::GenerateClassHierarchy"))
             {
                 IClassHierarchy ns = TangFactory.GetTang().GetClassHierarchy(clrDlls.ToArray());
-                ProtocolBufferClassHierarchy.Serialize(Constants.ClassHierarachyBin, ns);
+                ProtocolBufferClassHierarchy.Serialize(Constants.ClassHierarchyBin, ns);
 
-                LOGGER.Log(Level.Info, string.Format(CultureInfo.InvariantCulture, "Class hierarchy written to [{0}].", Path.Combine(Directory.GetCurrentDirectory(), Constants.ClassHierarachyBin)));
+                LOGGER.Log(Level.Info, string.Format(CultureInfo.InvariantCulture, "Class hierarchy written to [{0}].", Path.Combine(Directory.GetCurrentDirectory(), Constants.ClassHierarchyBin)));
             }
         }
 

http://git-wip-us.apache.org/repos/asf/incubator-reef/blob/8b7189bd/lang/cs/Org.Apache.REEF.Driver/Bridge/DriverBridge.cs
----------------------------------------------------------------------
diff --git a/lang/cs/Org.Apache.REEF.Driver/Bridge/DriverBridge.cs b/lang/cs/Org.Apache.REEF.Driver/Bridge/DriverBridge.cs
index ef71c79..6e02bff 100644
--- a/lang/cs/Org.Apache.REEF.Driver/Bridge/DriverBridge.cs
+++ b/lang/cs/Org.Apache.REEF.Driver/Bridge/DriverBridge.cs
@@ -146,7 +146,7 @@ namespace Org.Apache.REEF.Driver.Bridge
         {
             foreach (TraceListener listener in traceListeners)
             {
-                Logger.AddTraceListner(listener);
+                Logger.AddTraceListener(listener);
             }
             _logger = Logger.GetLogger(typeof(DriverBridge));
             _logger.Log(Level.Info, "Constructing DriverBridge");
@@ -243,7 +243,7 @@ namespace Org.Apache.REEF.Driver.Bridge
             foreach (var handler in _runningTaskHandlers)
             {
                 _runningTaskSubscriber.Subscribe(handler);
-                _logger.Log(Level.Verbose, "subscribed to IRunningask handler: " + handler);
+                _logger.Log(Level.Verbose, "subscribed to IRunningTask handler: " + handler);
             }
             handlers[Constants.Handlers[Constants.RunningTaskHandler]] = ClrHandlerHelper.CreateHandler(_runningTaskSubscriber);
 

http://git-wip-us.apache.org/repos/asf/incubator-reef/blob/8b7189bd/lang/cs/Org.Apache.REEF.Driver/Bridge/HttpServerHandler.cs
----------------------------------------------------------------------
diff --git a/lang/cs/Org.Apache.REEF.Driver/Bridge/HttpServerHandler.cs b/lang/cs/Org.Apache.REEF.Driver/Bridge/HttpServerHandler.cs
index c3b6cae..c757001 100644
--- a/lang/cs/Org.Apache.REEF.Driver/Bridge/HttpServerHandler.cs
+++ b/lang/cs/Org.Apache.REEF.Driver/Bridge/HttpServerHandler.cs
@@ -85,7 +85,7 @@ namespace Org.Apache.REEF.Driver.Bridge
             {
                 LOGGER.Log(Level.Info, "HttpHandler OnNext, handling http request.");
                 byte[] byteData = httpMessage.GetQueryReuestData();
-                AvroHttpRequest avroHttpRequest = AvroHttpSerializer.FromBytesWithJoson(byteData);
+                AvroHttpRequest avroHttpRequest = AvroHttpSerializer.FromBytesWithJson(byteData);
                 LOGGER.Log(Level.Info, string.Format(CultureInfo.CurrentCulture, "HttpHandler OnNext, requestData:", avroHttpRequest));
 
                 string spec = GetSpecification(avroHttpRequest.PathInfo);

http://git-wip-us.apache.org/repos/asf/incubator-reef/blob/8b7189bd/lang/cs/Org.Apache.REEF.Driver/Constants.cs
----------------------------------------------------------------------
diff --git a/lang/cs/Org.Apache.REEF.Driver/Defaults/DefaultClientCloseWithMessageHandler.cs b/lang/cs/Org.Apache.REEF.Driver/Defaults/DefaultClientCloseWithMessageHandler.cs
index ddf0a3a..101a037 100644
--- a/lang/cs/Org.Apache.REEF.Driver/Defaults/DefaultClientCloseWithMessageHandler.cs
+++ b/lang/cs/Org.Apache.REEF.Driver/Defaults/DefaultClientCloseWithMessageHandler.cs
@@ -37,7 +37,7 @@ namespace Org.Apache.REEF.Driver.Defaults
         
         public void OnNext(byte[] value)
         {
-            Exceptions.Throw(new InvalidOperationException("No handler bound for client Close With Message event:" + ByteUtilities.ByteArrarysToString(value)), 
+            Exceptions.Throw(new InvalidOperationException("No handler bound for client Close With Message event:" + ByteUtilities.ByteArraysToString(value)), 
                 Logger.GetLogger(typeof(DefaultClientCloseWithMessageHandler)));
         }
 

http://git-wip-us.apache.org/repos/asf/incubator-reef/blob/8b7189bd/lang/cs/Org.Apache.REEF.Driver/Defaults/DefaultClientMessageHandler.cs
----------------------------------------------------------------------
diff --git a/lang/cs/Org.Apache.REEF.Driver/Defaults/DefaultClientMessageHandler.cs b/lang/cs/Org.Apache.REEF.Driver/Defaults/DefaultClientMessageHandler.cs
index da9ef89..d10c917 100644
--- a/lang/cs/Org.Apache.REEF.Driver/Defaults/DefaultClientMessageHandler.cs
+++ b/lang/cs/Org.Apache.REEF.Driver/Defaults/DefaultClientMessageHandler.cs
@@ -38,7 +38,7 @@ namespace Org.Apache.REEF.Driver.Defaults
 
         public void OnNext(byte[] value)
         {
-            LOGGER.Log(Level.Info, "Received message: " + ByteUtilities.ByteArrarysToString(value));
+            LOGGER.Log(Level.Info, "Received message: " + ByteUtilities.ByteArraysToString(value));
         }
 
         public void OnError(Exception error)

http://git-wip-us.apache.org/repos/asf/incubator-reef/blob/8b7189bd/lang/cs/Org.Apache.REEF.Driver/Defaults/DefaultContextMessageHandler.cs
----------------------------------------------------------------------
diff --git a/lang/cs/Org.Apache.REEF.Driver/Defaults/DefaultContextMessageHandler.cs b/lang/cs/Org.Apache.REEF.Driver/Defaults/DefaultContextMessageHandler.cs
index 5e20da9..caecf38 100644
--- a/lang/cs/Org.Apache.REEF.Driver/Defaults/DefaultContextMessageHandler.cs
+++ b/lang/cs/Org.Apache.REEF.Driver/Defaults/DefaultContextMessageHandler.cs
@@ -26,7 +26,7 @@ using Org.Apache.REEF.Utilities.Logging;
 namespace Org.Apache.REEF.Driver.Defaults
 {
     /// <summary>
-    /// efault event handler for ContextMessage: Logging it.
+    /// Default event handler for ContextMessage: Logging it.
     /// </summary>
     public class DefaultContextMessageHandler : IObserver<IContextMessage>
     {
@@ -39,7 +39,7 @@ namespace Org.Apache.REEF.Driver.Defaults
 
         public void OnNext(IContextMessage value)
         {
-            LOGGER.Log(Level.Info, "Received ContextMessage: " + ByteUtilities.ByteArrarysToString(value.Message));
+            LOGGER.Log(Level.Info, "Received ContextMessage: " + ByteUtilities.ByteArraysToString(value.Message));
         }
 
         public void OnError(Exception error)

http://git-wip-us.apache.org/repos/asf/incubator-reef/blob/8b7189bd/lang/cs/Org.Apache.REEF.Driver/Defaults/DefaultEvaluatorRequestorHandler.cs
----------------------------------------------------------------------
diff --git a/lang/cs/Org.Apache.REEF.Driver/Defaults/DefaultEvaluatorRequestorHandler.cs b/lang/cs/Org.Apache.REEF.Driver/Defaults/DefaultEvaluatorRequestorHandler.cs
index 0617e29..a59b8bf 100644
--- a/lang/cs/Org.Apache.REEF.Driver/Defaults/DefaultEvaluatorRequestorHandler.cs
+++ b/lang/cs/Org.Apache.REEF.Driver/Defaults/DefaultEvaluatorRequestorHandler.cs
@@ -39,7 +39,7 @@ namespace Org.Apache.REEF.Driver.Defaults
 
         public void OnNext(IEvaluatorRequestor value)
         {
-            LOGGER.Log(Level.Info, "Default evaluator requstor: requesting 1 evaluator with 512 MB");
+            LOGGER.Log(Level.Info, "Default evaluator requestor: requesting 1 evaluator with 512 MB");
             int evaluatorsNumber = 1;
             int memory = 512;
             string rack = "WonderlandRack";

http://git-wip-us.apache.org/repos/asf/incubator-reef/blob/8b7189bd/lang/cs/Org.Apache.REEF.Driver/Defaults/DefaultHttpHandler.cs
----------------------------------------------------------------------
diff --git a/lang/cs/Org.Apache.REEF.Driver/Defaults/DefaultHttpHandler.cs b/lang/cs/Org.Apache.REEF.Driver/Defaults/DefaultHttpHandler.cs
index bcba2a7..37653b1 100644
--- a/lang/cs/Org.Apache.REEF.Driver/Defaults/DefaultHttpHandler.cs
+++ b/lang/cs/Org.Apache.REEF.Driver/Defaults/DefaultHttpHandler.cs
@@ -39,7 +39,7 @@ namespace Org.Apache.REEF.Driver.Defaults
             return "Ping";
         }
 
-        public void OnHttpRequest(ReefHttpRequest requet, ReefHttpResponse response) 
+        public void OnHttpRequest(ReefHttpRequest request, ReefHttpResponse response) 
         {
             LOGGER.Log(Level.Info, "OnHttpRequest in DefaultHttpHandler is called.");
             response.Status = HttpStatusCode.OK;

http://git-wip-us.apache.org/repos/asf/incubator-reef/blob/8b7189bd/lang/cs/Org.Apache.REEF.Driver/DriverConfigGenerator.cs
----------------------------------------------------------------------
diff --git a/lang/cs/Org.Apache.REEF.Driver/DriverConfigGenerator.cs b/lang/cs/Org.Apache.REEF.Driver/DriverConfigGenerator.cs
index c0e1691..89bb34f 100644
--- a/lang/cs/Org.Apache.REEF.Driver/DriverConfigGenerator.cs
+++ b/lang/cs/Org.Apache.REEF.Driver/DriverConfigGenerator.cs
@@ -71,16 +71,16 @@ namespace Org.Apache.REEF.Driver
 
             AvroConfigurationSerializer serializer = new AvroConfigurationSerializer();
 
-            IClassHierarchy drvierClassHierarchy = ProtocolBufferClassHierarchy.DeSerialize(DriverChFile);
+            IClassHierarchy driverClassHierarchy = ProtocolBufferClassHierarchy.DeSerialize(DriverChFile);
 
-            AvroConfiguration jobDriverAvroconfiguration = serializer.AvroDeseriaizeFromFile(JobDriverConfigFile);
-            IConfiguration jobDriverConfiguration = serializer.FromAvro(jobDriverAvroconfiguration, drvierClassHierarchy);
+            AvroConfiguration jobDriverAvroconfiguration = serializer.AvroDeserializeFromFile(JobDriverConfigFile);
+            IConfiguration jobDriverConfiguration = serializer.FromAvro(jobDriverAvroconfiguration, driverClassHierarchy);
 
-            AvroConfiguration httpAvroconfiguration = serializer.AvroDeseriaizeFromFile(HttpServerConfigFile);
-            IConfiguration httpConfiguration = serializer.FromAvro(httpAvroconfiguration, drvierClassHierarchy);
+            AvroConfiguration httpAvroconfiguration = serializer.AvroDeserializeFromFile(HttpServerConfigFile);
+            IConfiguration httpConfiguration = serializer.FromAvro(httpAvroconfiguration, driverClassHierarchy);
 
-            AvroConfiguration nameAvroconfiguration = serializer.AvroDeseriaizeFromFile(NameServerConfigFile);
-            IConfiguration nameConfiguration = serializer.FromAvro(nameAvroconfiguration, drvierClassHierarchy);
+            AvroConfiguration nameAvroconfiguration = serializer.AvroDeserializeFromFile(NameServerConfigFile);
+            IConfiguration nameConfiguration = serializer.FromAvro(nameAvroconfiguration, driverClassHierarchy);
 
             IConfiguration merged;
 

http://git-wip-us.apache.org/repos/asf/incubator-reef/blob/8b7189bd/lang/cs/Org.Apache.REEF.Driver/DriverConfiguration.cs
----------------------------------------------------------------------
diff --git a/lang/cs/Org.Apache.REEF.Driver/DriverConfiguration.cs b/lang/cs/Org.Apache.REEF.Driver/DriverConfiguration.cs
index c99036e..821517e 100644
--- a/lang/cs/Org.Apache.REEF.Driver/DriverConfiguration.cs
+++ b/lang/cs/Org.Apache.REEF.Driver/DriverConfiguration.cs
@@ -153,17 +153,17 @@ namespace Org.Apache.REEF.Driver
             new OptionalImpl<IObserver<IFailedEvaluator>>();
 
         /// <summary>
-        /// Additional set of string arguments that can be pssed to handlers through client
+        /// Additional set of string arguments that can be passed to handlers through client
         /// </summary>
         public static readonly OptionalParameter<string> CommandLineArguments = new OptionalParameter<string>();
 
         /// <summary>
-        /// The trace level of the TraceListner
+        /// The trace level of the TraceListener
         /// </summary>
         public static readonly OptionalParameter<string> CustomTraceLevel = new OptionalParameter<string>();
 
         /// <summary>
-        /// Additional set of trace listners provided by client
+        /// Additional set of trace listeners provided by client
         /// </summary>
         public static readonly OptionalParameter<TraceListener> CustomTraceListeners =
             new OptionalParameter<TraceListener>();

http://git-wip-us.apache.org/repos/asf/incubator-reef/blob/8b7189bd/lang/cs/Org.Apache.REEF.Driver/DriverConfigurationSettings.cs
----------------------------------------------------------------------
diff --git a/lang/cs/Org.Apache.REEF.Driver/DriverConfigurationSettings.cs b/lang/cs/Org.Apache.REEF.Driver/DriverConfigurationSettings.cs
index 85cfacf..68c10f6 100644
--- a/lang/cs/Org.Apache.REEF.Driver/DriverConfigurationSettings.cs
+++ b/lang/cs/Org.Apache.REEF.Driver/DriverConfigurationSettings.cs
@@ -29,10 +29,10 @@ namespace Org.Apache.REEF.Driver
         // default to _defaultSubmissionDirectory if not provided
         private string _submissionDirectory = "reefTmp/job_" + DateTime.Now.Millisecond;
 
-        // deault to 512MB if no value is provided
+        // default to 512MB if no value is provided
         private int _driverMemory = 512;
 
-        // folder path that constains clr dlls used by reef
+        // folder path that contains clr dlls used by reef
         private string _clrFolder = ".";
 
         // folder that contains jar File provided Byte REEF
@@ -58,7 +58,7 @@ namespace Org.Apache.REEF.Driver
             {
                 if (value < 0)
                 {
-                    throw new ArgumentException("driver memory cannot be negatvie value.");
+                    throw new ArgumentException("driver memory cannot be negative value.");
                 }
                 _driverMemory = value;
             }
@@ -99,7 +99,7 @@ namespace Org.Apache.REEF.Driver
 
         /// <summary>
         /// Driver job submission directory in (H)DFS where jar file shall be uploaded, default to a tmp directory with GUID name
-        /// If set by CLR user, the user must guarantee the uniquness of the directory across multiple jobs
+        /// If set by CLR user, the user must guarantee the uniqueness of the directory across multiple jobs
         /// </summary>
         public string SubmissionDirectory
         {

http://git-wip-us.apache.org/repos/asf/incubator-reef/blob/8b7189bd/lang/cs/Org.Apache.REEF.Driver/DriverSubmissionSettings.cs
----------------------------------------------------------------------
diff --git a/lang/cs/Org.Apache.REEF.Driver/DriverSubmissionSettings.cs b/lang/cs/Org.Apache.REEF.Driver/DriverSubmissionSettings.cs
index 15cb8ca..430464d 100644
--- a/lang/cs/Org.Apache.REEF.Driver/DriverSubmissionSettings.cs
+++ b/lang/cs/Org.Apache.REEF.Driver/DriverSubmissionSettings.cs
@@ -23,6 +23,7 @@ using Org.Apache.REEF.Utilities.Logging;
 namespace Org.Apache.REEF.Driver
 {
     // TODO: merge with EvaluatorConfigurations class
+    // TODO[REEF-842] Act on the obsoletes
     public class DriverSubmissionSettings
     {
         // default to "ReefDevClrBridge"
@@ -171,8 +172,14 @@ namespace Org.Apache.REEF.Driver
             }
         }
 
+        [Obsolete("Deprecated in 0.14, please use ToCommandLineArguments instead.")]
         public string ToComamndLineArguments()
         {
+            return ToCommandLineArguments();
+        }
+
+        public string ToCommandLineArguments()
+        {
             return
                 (RunOnYarn ? " -local false" : string.Empty) +
                 (!Submit ? " -submit false" : string.Empty) +

http://git-wip-us.apache.org/repos/asf/incubator-reef/blob/8b7189bd/lang/cs/Org.Apache.REEF.Evaluator.Tests/EvaluatorConfigurationsTests.cs
----------------------------------------------------------------------
diff --git a/lang/cs/Org.Apache.REEF.Evaluator.Tests/EvaluatorConfigurationsTests.cs b/lang/cs/Org.Apache.REEF.Evaluator.Tests/EvaluatorConfigurationsTests.cs
index 6c9385a..aa9864c 100644
--- a/lang/cs/Org.Apache.REEF.Evaluator.Tests/EvaluatorConfigurationsTests.cs
+++ b/lang/cs/Org.Apache.REEF.Evaluator.Tests/EvaluatorConfigurationsTests.cs
@@ -61,7 +61,7 @@ namespace Org.Apache.REEF.Evaluator.Tests
         public void TestEvaluatorConfigurationFile()
         {
             AvroConfigurationSerializer serializer = new AvroConfigurationSerializer();
-            var avroConfiguration = serializer.AvroDeseriaizeFromFile("evaluator.conf");
+            var avroConfiguration = serializer.AvroDeserializeFromFile("evaluator.conf");
 
             Assert.IsNotNull(avroConfiguration);
             Assert.AreEqual(avroConfiguration.language, AvroConfigurationSerializer.Java);

http://git-wip-us.apache.org/repos/asf/incubator-reef/blob/8b7189bd/lang/cs/Org.Apache.REEF.Evaluator.Tests/EvaluatorTests.cs
----------------------------------------------------------------------
diff --git a/lang/cs/Org.Apache.REEF.Evaluator.Tests/EvaluatorTests.cs b/lang/cs/Org.Apache.REEF.Evaluator.Tests/EvaluatorTests.cs
index 8779d8b..32fc095 100644
--- a/lang/cs/Org.Apache.REEF.Evaluator.Tests/EvaluatorTests.cs
+++ b/lang/cs/Org.Apache.REEF.Evaluator.Tests/EvaluatorTests.cs
@@ -48,7 +48,7 @@ namespace Org.Apache.REEF.Evaluator.Tests
             Assert.IsNotNull(tmp);
 
             AvroConfigurationSerializer serializer = new AvroConfigurationSerializer();
-            AvroConfiguration avroConfiguration = serializer.AvroDeseriaizeFromFile("evaluator.conf");
+            AvroConfiguration avroConfiguration = serializer.AvroDeserializeFromFile("evaluator.conf");
             Assert.IsNotNull(avroConfiguration);
 
             ICsConfigurationBuilder cb = TangFactory.GetTang().NewConfigurationBuilder();
@@ -84,7 +84,7 @@ namespace Org.Apache.REEF.Evaluator.Tests
 
         [TestMethod, Priority(0), TestCategory("Unit")]
         [Description("Test driver information extracted from Http server")]
-        public void CanExtractDriverInformaiton()
+        public void CanExtractDriverInformation()
         {
             const string infoString = "{\"remoteId\":\"socket://10.121.136.231:14272\",\"startTime\":\"2014 08 28 10:50:32\",\"services\":[{\"serviceName\":\"NameServer\",\"serviceInfo\":\"10.121.136.231:16663\"}]}";
             AvroDriverInfo info = AvroJsonSerializer<AvroDriverInfo>.FromString(infoString);

http://git-wip-us.apache.org/repos/asf/incubator-reef/blob/8b7189bd/lang/cs/Org.Apache.REEF.Evaluator/Evaluator.cs
----------------------------------------------------------------------
diff --git a/lang/cs/Org.Apache.REEF.Evaluator/Evaluator.cs b/lang/cs/Org.Apache.REEF.Evaluator/Evaluator.cs
index c114e7e..ed51e7d 100644
--- a/lang/cs/Org.Apache.REEF.Evaluator/Evaluator.cs
+++ b/lang/cs/Org.Apache.REEF.Evaluator/Evaluator.cs
@@ -70,7 +70,7 @@ namespace Org.Apache.REEF.Evaluator
                     DateTime.Now));
                 Stopwatch timer = new Stopwatch();
                 InitInjector();
-                SetCustomTraceListners();  // _logger is reset by this.
+                SetCustomTraceListeners();  // _logger is reset by this.
                 timer.Stop();
                 Console.WriteLine(string.Format(CultureInfo.InvariantCulture,
                     "EXIT: {0} Evaluator::InitInjector. Duration: [{1}].", DateTime.Now, timer.Elapsed));
@@ -96,7 +96,7 @@ namespace Org.Apache.REEF.Evaluator
                         Utilities.Diagnostics.Exceptions.Throw(e, _logger);
                     }
 
-                    // evaluator configuraiton file
+                    // evaluator configuration file
                     string evaluatorConfigurationPath = args[0];
 
                     // Parse the evaluator configuration.
@@ -213,7 +213,7 @@ namespace Org.Apache.REEF.Evaluator
                 _heartbeatMaxRetry = maxHeartbeatRetry;
             }
             _logger.Log(Level.Verbose,
-                "Evaluator heatrbeat max retry set to be " + _heartbeatMaxRetry + " times.");
+                "Evaluator heartbeat max retry set to be " + _heartbeatMaxRetry + " times.");
         }
 
 
@@ -265,10 +265,10 @@ namespace Org.Apache.REEF.Evaluator
         /// <returns></returns>
         private static RuntimeClock InstantiateClock()
         {
-            IConfiguration clockConfiguraiton = new ConfigurationModuleBuilder().Build().Build();
+            IConfiguration clockConfiguration = new ConfigurationModuleBuilder().Build().Build();
             try
             {
-                return TangFactory.GetTang().NewInjector(clockConfiguraiton).GetInstance<RuntimeClock>();
+                return TangFactory.GetTang().NewInjector(clockConfiguration).GetInstance<RuntimeClock>();
             }
             catch (Exception exception)
             {
@@ -276,7 +276,7 @@ namespace Org.Apache.REEF.Evaluator
             } 
         }
 
-        private static void SetCustomTraceListners()
+        private static void SetCustomTraceListeners()
         {
             ISet<TraceListener> customTraceListeners;
             try
@@ -286,12 +286,12 @@ namespace Org.Apache.REEF.Evaluator
             catch (Exception e)
             {
                 Utilities.Diagnostics.Exceptions.Caught(e, Level.Error, _logger);
-                // custom trace listner not set properly, use empty set
+                // custom trace listener not set properly, use empty set
                 customTraceListeners = new HashSet<TraceListener>();
             }
             foreach (TraceListener listener in customTraceListeners)
             {
-                Logger.AddTraceListner(listener);
+                Logger.AddTraceListener(listener);
             }
             _logger = Logger.GetLogger(typeof(Evaluator));
             CustomTraceLevel traceLevel = _injector.GetInstance<CustomTraceLevel>();

http://git-wip-us.apache.org/repos/asf/incubator-reef/blob/8b7189bd/lang/cs/Org.Apache.REEF.Examples.AllHandlers/AllHandlers.cs
----------------------------------------------------------------------
diff --git a/lang/cs/Org.Apache.REEF.Examples.AllHandlers/AllHandlers.cs b/lang/cs/Org.Apache.REEF.Examples.AllHandlers/AllHandlers.cs
index 330874c..57d01e4 100644
--- a/lang/cs/Org.Apache.REEF.Examples.AllHandlers/AllHandlers.cs
+++ b/lang/cs/Org.Apache.REEF.Examples.AllHandlers/AllHandlers.cs
@@ -73,13 +73,13 @@ namespace Org.Apache.REEF.Examples.AllHandlers
                 .Set(DriverConfiguration.OnDriverRestartTaskRunning, GenericType<HelloDriverRestartRunningTaskHandler>.Class)
                 .Build();
 
-            var driverCondig = TangFactory.GetTang().NewConfigurationBuilder(helloDriverConfiguration)
+            var driverConfig = TangFactory.GetTang().NewConfigurationBuilder(helloDriverConfiguration)
                 .BindSetEntry<DriverBridgeConfigurationOptions.SetOfAssemblies, string>(typeof(HelloTask).Assembly.GetName().Name)
                 .BindSetEntry<DriverBridgeConfigurationOptions.SetOfAssemblies, string>(typeof(NameClient).Assembly.GetName().Name)
                 .Build();
 
             var helloJobSubmission = _jobSubmissionBuilderFactory.GetJobSubmissionBuilder()
-                .AddDriverConfiguration(driverCondig)
+                .AddDriverConfiguration(driverConfig)
                 .AddGlobalAssemblyForType(typeof(HelloDriverStartHandler))
                 .SetJobIdentifier("HelloDriver")
                 .Build();

http://git-wip-us.apache.org/repos/asf/incubator-reef/blob/8b7189bd/lang/cs/Org.Apache.REEF.Examples.AllHandlers/HelloFailedTaskHandler.cs
----------------------------------------------------------------------
diff --git a/lang/cs/Org.Apache.REEF.Examples.AllHandlers/HelloFailedTaskHandler.cs b/lang/cs/Org.Apache.REEF.Examples.AllHandlers/HelloFailedTaskHandler.cs
index 4b19bea..fc806ff 100644
--- a/lang/cs/Org.Apache.REEF.Examples.AllHandlers/HelloFailedTaskHandler.cs
+++ b/lang/cs/Org.Apache.REEF.Examples.AllHandlers/HelloFailedTaskHandler.cs
@@ -48,7 +48,7 @@ namespace Org.Apache.REEF.Examples.AllHandlers
                 failedTask.Reason.IsPresent() ? failedTask.Reason.Value : string.Empty,
                 failedTask.Message,
                 failedTask.Description.IsPresent() ? failedTask.Description.Value : string.Empty,
-                failedTask.Data.IsPresent() ? ByteUtilities.ByteArrarysToString(failedTask.Data.Value) : string.Empty);
+                failedTask.Data.IsPresent() ? ByteUtilities.ByteArraysToString(failedTask.Data.Value) : string.Empty);
 
             Console.WriteLine(errorMessage);
 

http://git-wip-us.apache.org/repos/asf/incubator-reef/blob/8b7189bd/lang/cs/Org.Apache.REEF.Examples.AllHandlers/HelloHttpHandler.cs
----------------------------------------------------------------------
diff --git a/lang/cs/Org.Apache.REEF.Examples.AllHandlers/HelloHttpHandler.cs b/lang/cs/Org.Apache.REEF.Examples.AllHandlers/HelloHttpHandler.cs
index 3c4899c..afb5101 100644
--- a/lang/cs/Org.Apache.REEF.Examples.AllHandlers/HelloHttpHandler.cs
+++ b/lang/cs/Org.Apache.REEF.Examples.AllHandlers/HelloHttpHandler.cs
@@ -46,12 +46,11 @@ namespace Org.Apache.REEF.Examples.AllHandlers
         /// <summary>
         /// Sample code after receiving http request and send back the http response
         /// </summary>
-        /// <param name="requet"></param>
+        /// <param name="request"></param>
         /// <param name="response"></param>
-        public void OnHttpRequest(ReefHttpRequest requet, ReefHttpResponse response)  
+        public void OnHttpRequest(ReefHttpRequest request, ReefHttpResponse response)  
         {
-            Logger.Log(Level.Info, string.Format(CultureInfo.CurrentCulture, "HelloHttpHandler OnHttpRequest: URL: {0}, QueryString: {1}, inputStream: {2}.", requet.Url, requet.Querystring, ByteUtilities.ByteArrarysToString(requet.InputStream)));
-            response.Status = HttpStatusCode.OK;
+            Logger.Log(Level.Info, string.Format(CultureInfo.CurrentCulture, "HelloHttpHandler OnHttpRequest: URL: {0}, QueryString: {1}, inputStream: {2}.", request.Url, request.Querystring, ByteUtilities.ByteArraysToString(request.InputStream)));response.Status = HttpStatusCode.OK;
             response.OutputStream =
                 ByteUtilities.StringToByteArrays("Byte array returned from HelloHttpHandler in CLR!!!");
         }

http://git-wip-us.apache.org/repos/asf/incubator-reef/blob/8b7189bd/lang/cs/Org.Apache.REEF.Examples.AllHandlers/HelloTaskCompletedHandler.cs
----------------------------------------------------------------------
diff --git a/lang/cs/Org.Apache.REEF.Examples.AllHandlers/HelloTaskCompletedHandler.cs b/lang/cs/Org.Apache.REEF.Examples.AllHandlers/HelloTaskCompletedHandler.cs
index aa035b0..5b2e01a 100644
--- a/lang/cs/Org.Apache.REEF.Examples.AllHandlers/HelloTaskCompletedHandler.cs
+++ b/lang/cs/Org.Apache.REEF.Examples.AllHandlers/HelloTaskCompletedHandler.cs
@@ -40,7 +40,7 @@ namespace Org.Apache.REEF.Examples.AllHandlers
         /// <param name="completedTask"></param>
         public void OnNext(ICompletedTask completedTask)
         {
-            Console.WriteLine("Received CompletedTask: {0}, with message [{1}].", completedTask.Id, ByteUtilities.ByteArrarysToString(completedTask.Message));
+            Console.WriteLine("Received CompletedTask: {0}, with message [{1}].", completedTask.Id, ByteUtilities.ByteArraysToString(completedTask.Message));
         }
 
         public void OnError(Exception error)

http://git-wip-us.apache.org/repos/asf/incubator-reef/blob/8b7189bd/lang/cs/Org.Apache.REEF.Examples/DriverRestart/HelloRestartTask.cs
----------------------------------------------------------------------
diff --git a/lang/cs/Org.Apache.REEF.Examples/DriverRestart/HelloRestartTask.cs b/lang/cs/Org.Apache.REEF.Examples/DriverRestart/HelloRestartTask.cs
index 11ed148..3efba7a 100644
--- a/lang/cs/Org.Apache.REEF.Examples/DriverRestart/HelloRestartTask.cs
+++ b/lang/cs/Org.Apache.REEF.Examples/DriverRestart/HelloRestartTask.cs
@@ -56,7 +56,7 @@ namespace Org.Apache.REEF.Examples.DriverRestart
 
         public void Handle(IDriverMessage message)
         {
-            Logger.Log(Level.Verbose, "Receieved a message from driver. We should exit now...");
+            Logger.Log(Level.Verbose, "Received a message from driver. We should exit now...");
             _exit = true;
         }
 

http://git-wip-us.apache.org/repos/asf/incubator-reef/blob/8b7189bd/lang/cs/Org.Apache.REEF.Examples/MachineLearning/KMeans/Centroids.cs
----------------------------------------------------------------------
diff --git a/lang/cs/Org.Apache.REEF.Examples/MachineLearning/KMeans/Centroids.cs b/lang/cs/Org.Apache.REEF.Examples/MachineLearning/KMeans/Centroids.cs
index 0ceb4ed..0d3b4c7 100644
--- a/lang/cs/Org.Apache.REEF.Examples/MachineLearning/KMeans/Centroids.cs
+++ b/lang/cs/Org.Apache.REEF.Examples/MachineLearning/KMeans/Centroids.cs
@@ -38,7 +38,7 @@ namespace Org.Apache.REEF.Examples.MachineLearning.KMeans
         /// <returns>the serialized string</returns>
         public override string ToString()
         {
-            return ByteUtilities.ByteArrarysToString(new CentroidsCodec().Encode(this));
+            return ByteUtilities.ByteArraysToString(new CentroidsCodec().Encode(this));
         }
     }
 }

http://git-wip-us.apache.org/repos/asf/incubator-reef/blob/8b7189bd/lang/cs/Org.Apache.REEF.Examples/MachineLearning/KMeans/ProcessedResults.cs
----------------------------------------------------------------------
diff --git a/lang/cs/Org.Apache.REEF.Examples/MachineLearning/KMeans/ProcessedResults.cs b/lang/cs/Org.Apache.REEF.Examples/MachineLearning/KMeans/ProcessedResults.cs
index 3e3394f..1f86c24 100644
--- a/lang/cs/Org.Apache.REEF.Examples/MachineLearning/KMeans/ProcessedResults.cs
+++ b/lang/cs/Org.Apache.REEF.Examples/MachineLearning/KMeans/ProcessedResults.cs
@@ -48,7 +48,7 @@ namespace Org.Apache.REEF.Examples.MachineLearning.KMeans
         /// <returns>seralized string</returns>
         public override string ToString()
         {
-            return ByteUtilities.ByteArrarysToString(new ProcessedResultsCodec().Encode(this));
+            return ByteUtilities.ByteArraysToString(new ProcessedResultsCodec().Encode(this));
         }
     }
 }

http://git-wip-us.apache.org/repos/asf/incubator-reef/blob/8b7189bd/lang/cs/Org.Apache.REEF.Examples/MachineLearning/KMeans/codecs/ProcessedResultsCodec.cs
----------------------------------------------------------------------
diff --git a/lang/cs/Org.Apache.REEF.Examples/MachineLearning/KMeans/codecs/ProcessedResultsCodec.cs b/lang/cs/Org.Apache.REEF.Examples/MachineLearning/KMeans/codecs/ProcessedResultsCodec.cs
index 8166030..4a212ee 100644
--- a/lang/cs/Org.Apache.REEF.Examples/MachineLearning/KMeans/codecs/ProcessedResultsCodec.cs
+++ b/lang/cs/Org.Apache.REEF.Examples/MachineLearning/KMeans/codecs/ProcessedResultsCodec.cs
@@ -44,10 +44,10 @@ namespace Org.Apache.REEF.Examples.MachineLearning.KMeans.codecs
 
         public ProcessedResults Decode(byte[] data)
         {
-            string[] parts = ByteUtilities.ByteArrarysToString(data).Split('+');
+            string[] parts = ByteUtilities.ByteArraysToString(data).Split('+');
             if (parts.Count() != 2)
             {
-                throw new ArgumentException("cannot deserialize from" + ByteUtilities.ByteArrarysToString(data));
+                throw new ArgumentException("cannot deserialize from" + ByteUtilities.ByteArraysToString(data));
             }
             float loss = float.Parse(parts[0], CultureInfo.InvariantCulture);
             List<PartialMean> means = parts[1].Split('@').Select(PartialMean.FromString).ToList();

http://git-wip-us.apache.org/repos/asf/incubator-reef/blob/8b7189bd/lang/cs/Org.Apache.REEF.Examples/Tasks/HelloTask/HelloTask.cs
----------------------------------------------------------------------
diff --git a/lang/cs/Org.Apache.REEF.Examples/Tasks/HelloTask/HelloTask.cs b/lang/cs/Org.Apache.REEF.Examples/Tasks/HelloTask/HelloTask.cs
index ccfeb01..12e9e8d 100644
--- a/lang/cs/Org.Apache.REEF.Examples/Tasks/HelloTask/HelloTask.cs
+++ b/lang/cs/Org.Apache.REEF.Examples/Tasks/HelloTask/HelloTask.cs
@@ -115,7 +115,7 @@ namespace Org.Apache.REEF.Examples.Tasks.HelloTask
                 LOGGER.Log(Level.Verbose, "Receieved a message from driver, handling it with HelloDriverMessageHandler");
                 if (value.Message.IsPresent())
                 {
-                    message = ByteUtilities.ByteArrarysToString(value.Message.Value);
+                    message = ByteUtilities.ByteArraysToString(value.Message.Value);
                 }
                 _parentTask.HandleDriverMessage(message);
             }

http://git-wip-us.apache.org/repos/asf/incubator-reef/blob/8b7189bd/lang/cs/Org.Apache.REEF.IO/FileSystem/Hadoop/HadoopFileSystemConfigurationProvider.cs
----------------------------------------------------------------------
diff --git a/lang/cs/Org.Apache.REEF.IO/FileSystem/Hadoop/HadoopFileSystemConfigurationProvider.cs b/lang/cs/Org.Apache.REEF.IO/FileSystem/Hadoop/HadoopFileSystemConfigurationProvider.cs
index 84111b3..d01469e 100644
--- a/lang/cs/Org.Apache.REEF.IO/FileSystem/Hadoop/HadoopFileSystemConfigurationProvider.cs
+++ b/lang/cs/Org.Apache.REEF.IO/FileSystem/Hadoop/HadoopFileSystemConfigurationProvider.cs
@@ -27,7 +27,7 @@ using Org.Apache.REEF.Tang.Util;
 namespace Org.Apache.REEF.IO.FileSystem.Hadoop
 {
     /// <summary>
-    /// This provider provides configuration for HardoopFileSystem
+    /// This provider provides configuration for HadoopFileSystem
     /// The client that is going to use HadoopFileSystem in its driver and evaluators should set 
     /// configuration data through HadoopFileSystemConfiguration module in he client's configuration
     /// </summary>

http://git-wip-us.apache.org/repos/asf/incubator-reef/blob/8b7189bd/lang/cs/Org.Apache.REEF.Network.Examples.Client/BroadcastAndReduceClient.cs
----------------------------------------------------------------------
diff --git a/lang/cs/Org.Apache.REEF.Network.Examples.Client/BroadcastAndReduceClient.cs b/lang/cs/Org.Apache.REEF.Network.Examples.Client/BroadcastAndReduceClient.cs
index 1931317..a33fd61 100644
--- a/lang/cs/Org.Apache.REEF.Network.Examples.Client/BroadcastAndReduceClient.cs
+++ b/lang/cs/Org.Apache.REEF.Network.Examples.Client/BroadcastAndReduceClient.cs
@@ -94,13 +94,13 @@ namespace Org.Apache.REEF.Network.Examples.Client
             TestRun(merged, typeof(BroadcastReduceDriver), numTasks, "BroadcastReduceDriver", runPlatform);
         }
 
-        internal static void TestRun(IConfiguration driverCondig, Type globalAssemblyType, int numberOfEvaluator, string jobIdentifier = "myDriver", string runOnYarn = "local", string runtimeFolder = DefaultRuntimeFolder)
+        internal static void TestRun(IConfiguration driverConfig, Type globalAssemblyType, int numberOfEvaluator, string jobIdentifier = "myDriver", string runOnYarn = "local", string runtimeFolder = DefaultRuntimeFolder)
         {
             IInjector injector = TangFactory.GetTang().NewInjector(GetRuntimeConfiguration(runOnYarn, numberOfEvaluator, runtimeFolder));
             var reefClient = injector.GetInstance<IREEFClient>();
             var jobSubmissionBuilderFactory = injector.GetInstance<JobSubmissionBuilderFactory>();
             var jobSubmission = jobSubmissionBuilderFactory.GetJobSubmissionBuilder()
-                .AddDriverConfiguration(driverCondig)
+                .AddDriverConfiguration(driverConfig)
                 .AddGlobalAssemblyForType(globalAssemblyType)
                 .SetJobIdentifier(jobIdentifier)
                 .Build();

http://git-wip-us.apache.org/repos/asf/incubator-reef/blob/8b7189bd/lang/cs/Org.Apache.REEF.Network.Examples/GroupCommunication/PipelineBroadcastReduceDriverAndTasks/PipelinedBroadcastReduceDriver.cs
----------------------------------------------------------------------
diff --git a/lang/cs/Org.Apache.REEF.Network.Examples/GroupCommunication/PipelineBroadcastReduceDriverAndTasks/PipelinedBroadcastReduceDriver.cs b/lang/cs/Org.Apache.REEF.Network.Examples/GroupCommunication/PipelineBroadcastReduceDriverAndTasks/PipelinedBroadcastReduceDriver.cs
index 90c0709..6e5ef7b 100644
--- a/lang/cs/Org.Apache.REEF.Network.Examples/GroupCommunication/PipelineBroadcastReduceDriverAndTasks/PipelinedBroadcastReduceDriver.cs
+++ b/lang/cs/Org.Apache.REEF.Network.Examples/GroupCommunication/PipelineBroadcastReduceDriverAndTasks/PipelinedBroadcastReduceDriver.cs
@@ -279,7 +279,7 @@ namespace Org.Apache.REEF.Network.Examples.GroupCommunication.PipelineBroadcastR
                 if (data.Length%sizeof (Int32) != 0)
                 {
                     throw new Exception(
-                        "error inside integer array decoder, byte array length not a multiple of interger size");
+                        "error inside integer array decoder, byte array length not a multiple of integer size");
                 }
 
                 var result = new int[data.Length/sizeof (Int32)];

http://git-wip-us.apache.org/repos/asf/incubator-reef/blob/8b7189bd/lang/cs/Org.Apache.REEF.Network.Tests/GroupCommunication/GroupCommunicationTests.cs
----------------------------------------------------------------------
diff --git a/lang/cs/Org.Apache.REEF.Network.Tests/GroupCommunication/GroupCommunicationTests.cs b/lang/cs/Org.Apache.REEF.Network.Tests/GroupCommunication/GroupCommunicationTests.cs
index 62a6a3f..653d14a 100644
--- a/lang/cs/Org.Apache.REEF.Network.Tests/GroupCommunication/GroupCommunicationTests.cs
+++ b/lang/cs/Org.Apache.REEF.Network.Tests/GroupCommunication/GroupCommunicationTests.cs
@@ -121,13 +121,13 @@ namespace Org.Apache.REEF.Network.Tests.GroupCommunication
                     broadcastOperatorName,
                     masterTaskId,
                     TopologyTypes.Flat,
-                    GetDefaulDataConverterConfig())
+                    GetDefaultDataConverterConfig())
                 .AddReduce<int>(
                     reduceOperatorName,
                     masterTaskId,
                     TopologyTypes.Flat,
-                    GetDefaulDataConverterConfig(),
-                    GetDefaulReduceFuncConfig())
+                    GetDefaultDataConverterConfig(),
+                    GetDefaultReduceFuncConfig())
                 .Build();
 
             var commGroups = CommGroupClients(groupName, numTasks, groupCommunicationDriver, commGroup, GetDefaultCodecConfig());
@@ -247,13 +247,13 @@ namespace Org.Apache.REEF.Network.Tests.GroupCommunication
                     scatterOperatorName,
                     masterTaskId,
                     TopologyTypes.Flat,
-                    GetDefaulDataConverterConfig())
+                    GetDefaultDataConverterConfig())
                 .AddReduce<int>(
                         reduceOperatorName,
                         masterTaskId,
                         TopologyTypes.Flat,
-                        GetDefaulReduceFuncConfig(),
-                        GetDefaulDataConverterConfig())
+                        GetDefaultReduceFuncConfig(),
+                        GetDefaultDataConverterConfig())
                 .Build();
 
             List<ICommunicationGroupClient> commGroups = CommGroupClients(groupName, numTasks, groupCommDriver, commGroup, GetDefaultCodecConfig());
@@ -415,7 +415,7 @@ namespace Org.Apache.REEF.Network.Tests.GroupCommunication
             IGroupCommDriver groupCommDriver = GetInstanceOfGroupCommDriver(driverId, masterTaskId, groupName, fanOut, numTasks);
 
             var commGroup = groupCommDriver.DefaultGroup
-                .AddReduce<int>(operatorName, "task0", TopologyTypes.Flat, GetDefaulDataConverterConfig(), GetDefaulReduceFuncConfig())
+                .AddReduce<int>(operatorName, "task0", TopologyTypes.Flat, GetDefaultDataConverterConfig(), GetDefaultReduceFuncConfig())
                 .Build();
 
             List<ICommunicationGroupClient> commGroups = CommGroupClients(groupName, numTasks, groupCommDriver, commGroup, GetDefaultCodecConfig());
@@ -450,7 +450,7 @@ namespace Org.Apache.REEF.Network.Tests.GroupCommunication
             IGroupCommDriver groupCommDriver = GetInstanceOfGroupCommDriver(driverId, masterTaskId, groupName, fanOut, numTasks);
 
             var commGroup = groupCommDriver.DefaultGroup
-                .AddReduce<int>(operatorName, "task0", TopologyTypes.Flat,GetDefaulDataConverterConfig(), GetDefaulReduceFuncConfig())
+                .AddReduce<int>(operatorName, "task0", TopologyTypes.Flat, GetDefaultDataConverterConfig(), GetDefaultReduceFuncConfig())
                 .Build();
 
             List<ICommunicationGroupClient> commGroups = CommGroupClients(groupName, numTasks, groupCommDriver, commGroup, GetDefaultCodecConfig());
@@ -572,7 +572,7 @@ namespace Org.Apache.REEF.Network.Tests.GroupCommunication
             IGroupCommDriver groupCommDriver = GetInstanceOfGroupCommDriver(driverId, masterTaskId, groupName, fanOut, numTasks);
 
             var commGroup = groupCommDriver.DefaultGroup
-                .AddScatter<int>(operatorName, masterTaskId, TopologyTypes.Flat, GetDefaulDataConverterConfig(), GetDefaulReduceFuncConfig())
+                .AddScatter<int>(operatorName, masterTaskId, TopologyTypes.Flat, GetDefaultDataConverterConfig(), GetDefaultReduceFuncConfig())
                 .Build();
 
             List<ICommunicationGroupClient> commGroups = CommGroupClients(groupName, numTasks, groupCommDriver, commGroup, GetDefaultCodecConfig());
@@ -622,7 +622,7 @@ namespace Org.Apache.REEF.Network.Tests.GroupCommunication
             IGroupCommDriver groupCommDriver = GetInstanceOfGroupCommDriver(driverId, masterTaskId, groupName, fanOut, numTasks);
 
             var commGroup = groupCommDriver.DefaultGroup
-                .AddScatter<int>(operatorName, masterTaskId, TopologyTypes.Flat, GetDefaulDataConverterConfig())
+                .AddScatter<int>(operatorName, masterTaskId, TopologyTypes.Flat, GetDefaultDataConverterConfig())
                 .Build();
 
             List<ICommunicationGroupClient> commGroups = CommGroupClients(groupName, numTasks, groupCommDriver, commGroup, GetDefaultCodecConfig());
@@ -669,7 +669,7 @@ namespace Org.Apache.REEF.Network.Tests.GroupCommunication
             IGroupCommDriver groupCommDriver = GetInstanceOfGroupCommDriver(driverId, masterTaskId, groupName, fanOut, numTasks);
 
             var commGroup = groupCommDriver.DefaultGroup
-                .AddScatter<int>(operatorName, masterTaskId, TopologyTypes.Flat, GetDefaulDataConverterConfig())
+                .AddScatter<int>(operatorName, masterTaskId, TopologyTypes.Flat, GetDefaultDataConverterConfig())
                 .Build();
 
             List<ICommunicationGroupClient> commGroups = CommGroupClients(groupName, numTasks, groupCommDriver, commGroup, GetDefaultCodecConfig());
@@ -707,7 +707,7 @@ namespace Org.Apache.REEF.Network.Tests.GroupCommunication
         public void TestConfigurationBroadcastSpec()
         {
             FlatTopology<int> topology = new FlatTopology<int>("Operator", "Operator", "task1", "driverid",
-                new BroadcastOperatorSpec("Sender", GetDefaultCodecConfig(), GetDefaulDataConverterConfig()));
+                new BroadcastOperatorSpec("Sender", GetDefaultCodecConfig(), GetDefaultDataConverterConfig()));
 
             topology.AddTask("task1");
             var conf = topology.GetTaskConfiguration("task1");
@@ -727,7 +727,7 @@ namespace Org.Apache.REEF.Network.Tests.GroupCommunication
         public void TestConfigurationReduceSpec()
         {
             FlatTopology<int> topology = new FlatTopology<int>("Operator", "Group", "task1", "driverid",
-                new ReduceOperatorSpec("task1", Configurations.Merge(GetDefaultCodecConfig(), GetDefaulDataConverterConfig(),  GetDefaulReduceFuncConfig())));
+                new ReduceOperatorSpec("task1", Configurations.Merge(GetDefaultCodecConfig(), GetDefaultDataConverterConfig(),  GetDefaultReduceFuncConfig())));
 
             topology.AddTask("task1");
             var conf2 = topology.GetTaskConfiguration("task1");
@@ -871,14 +871,14 @@ namespace Org.Apache.REEF.Network.Tests.GroupCommunication
                 .Build();
         }
 
-        private static IConfiguration GetDefaulReduceFuncConfig()
+        private static IConfiguration GetDefaultReduceFuncConfig()
         {
             return ReduceFunctionConfiguration<int>.Conf
                 .Set(ReduceFunctionConfiguration<int>.ReduceFunction, GenericType<SumFunction>.Class)
                 .Build();
         }
 
-        private static IConfiguration GetDefaulDataConverterConfig()
+        private static IConfiguration GetDefaultDataConverterConfig()
         {
             return PipelineDataConverterConfiguration<int>.Conf
                 .Set(PipelineDataConverterConfiguration<int>.DataConverter, GenericType<DefaultPipelineDataConverter<int>>.Class)

http://git-wip-us.apache.org/repos/asf/incubator-reef/blob/8b7189bd/lang/cs/Org.Apache.REEF.Network/Group/Config/CodecConfiguration.cs
----------------------------------------------------------------------
diff --git a/lang/cs/Org.Apache.REEF.Network/Group/Config/CodecConfiguration.cs b/lang/cs/Org.Apache.REEF.Network/Group/Config/CodecConfiguration.cs
index 7836c85..de1b9cb 100644
--- a/lang/cs/Org.Apache.REEF.Network/Group/Config/CodecConfiguration.cs
+++ b/lang/cs/Org.Apache.REEF.Network/Group/Config/CodecConfiguration.cs
@@ -27,7 +27,7 @@ namespace Org.Apache.REEF.Network.Group.Config
     public class CodecConfiguration<T> : ConfigurationModuleBuilder
     {
         /// <summary>
-        /// RequiredImpl for Codec. Client needs to set implementation for this paramter
+        /// RequiredImpl for Codec. Client needs to set implementation for this parameter
         /// </summary>
         public static readonly RequiredImpl<ICodec<T>> Codec = new RequiredImpl<ICodec<T>>();
 

http://git-wip-us.apache.org/repos/asf/incubator-reef/blob/8b7189bd/lang/cs/Org.Apache.REEF.Network/Group/Driver/ICommunicationGroupDriver.cs
----------------------------------------------------------------------
diff --git a/lang/cs/Org.Apache.REEF.Network/Group/Driver/ICommunicationGroupDriver.cs b/lang/cs/Org.Apache.REEF.Network/Group/Driver/ICommunicationGroupDriver.cs
index 240d244..60a7329 100644
--- a/lang/cs/Org.Apache.REEF.Network/Group/Driver/ICommunicationGroupDriver.cs
+++ b/lang/cs/Org.Apache.REEF.Network/Group/Driver/ICommunicationGroupDriver.cs
@@ -71,7 +71,7 @@ namespace Org.Apache.REEF.Network.Group.Driver
         /// </summary>
         /// <param name="operatorName">The name of the scatter operator</param>
         /// <param name="senderId">The sender id</param>
-        /// <param name="topologyType">type of topology used in the operaor</param>
+        /// <param name="topologyType">type of topology used in the operator</param>
         /// <returns>The same CommunicationGroupDriver with the added Scatter operator info</returns>
         ICommunicationGroupDriver AddScatter(string operatorName, string senderId, TopologyTypes topologyType = TopologyTypes.Flat);
 
@@ -82,7 +82,7 @@ namespace Org.Apache.REEF.Network.Group.Driver
         /// <param name="configurations">The configuration for task</param>
         /// <param name="operatorName">The name of the scatter operator</param>
         /// <param name="senderId">The sender id</param>
-        /// <param name="topologyType">type of topology used in the operaor</param>
+        /// <param name="topologyType">type of topology used in the operator</param>
         /// <returns>The same CommunicationGroupDriver with the added Scatter operator info</returns>
         ICommunicationGroupDriver AddScatter<T>(string operatorName, string senderId, TopologyTypes topologyType, params IConfiguration[] configurations);
 

http://git-wip-us.apache.org/repos/asf/incubator-reef/blob/8b7189bd/lang/cs/Org.Apache.REEF.Network/Group/Operators/IOperatorSpec.cs
----------------------------------------------------------------------
diff --git a/lang/cs/Org.Apache.REEF.Network/Group/Operators/IOperatorSpec.cs b/lang/cs/Org.Apache.REEF.Network/Group/Operators/IOperatorSpec.cs
index 920873b..cabbea2 100644
--- a/lang/cs/Org.Apache.REEF.Network/Group/Operators/IOperatorSpec.cs
+++ b/lang/cs/Org.Apache.REEF.Network/Group/Operators/IOperatorSpec.cs
@@ -17,6 +17,7 @@
  * under the License.
  */
 
+using System;
 using Org.Apache.REEF.Tang.Interface;
 
 namespace Org.Apache.REEF.Network.Group.Operators
@@ -24,8 +25,12 @@ namespace Org.Apache.REEF.Network.Group.Operators
     /// <summary>
     /// The specification used to define Broadcast Operators.
     /// </summary>
+    // TODO[REEF-842] Act on the obsoletes
     public interface IOperatorSpec
     {
+        [Obsolete("Deprecated in 0.14, please use Configuration instead.")]
         IConfiguration Configiration { get; }
+
+        IConfiguration Configuration { get; }
     }
-}
\ No newline at end of file
+}

http://git-wip-us.apache.org/repos/asf/incubator-reef/blob/8b7189bd/lang/cs/Org.Apache.REEF.Network/Group/Operators/Impl/BroadcastOperatorSpec.cs
----------------------------------------------------------------------
diff --git a/lang/cs/Org.Apache.REEF.Network/Group/Operators/Impl/BroadcastOperatorSpec.cs b/lang/cs/Org.Apache.REEF.Network/Group/Operators/Impl/BroadcastOperatorSpec.cs
index ea62588..c3652c9 100644
--- a/lang/cs/Org.Apache.REEF.Network/Group/Operators/Impl/BroadcastOperatorSpec.cs
+++ b/lang/cs/Org.Apache.REEF.Network/Group/Operators/Impl/BroadcastOperatorSpec.cs
@@ -17,6 +17,7 @@
  * under the License.
  */
 
+using System;
 using Org.Apache.REEF.Tang.Implementations.Configuration;
 using Org.Apache.REEF.Tang.Interface;
 
@@ -25,6 +26,7 @@ namespace Org.Apache.REEF.Network.Group.Operators.Impl
     /// <summary>
     /// The specification used to define Broadcast Operators.
     /// </summary>
+    /// TODO[REEF-842] Act on the obsoletes
     public class BroadcastOperatorSpec : IOperatorSpec
     {
         /// <summary>
@@ -35,7 +37,7 @@ namespace Org.Apache.REEF.Network.Group.Operators.Impl
         public BroadcastOperatorSpec(string senderId, params IConfiguration[] configurations)
         {
             SenderId = senderId;
-            Configiration = Configurations.Merge(configurations);
+            Configuration = Configurations.Merge(configurations);
         }
 
         /// <summary>
@@ -46,6 +48,15 @@ namespace Org.Apache.REEF.Network.Group.Operators.Impl
         /// <summary>
         /// Returns the Configuration for Codec, ReduceFunction and DataConverter
         /// </summary>
-        public IConfiguration Configiration { get; private set; }
+        [Obsolete("Deprecated in 0.14, please use Configuration instead.")]
+        public IConfiguration Configiration
+        {
+            get { return Configuration; }
+            private set { Configuration = value; }
+        }
+        /// <summary>
+        /// Returns the Configuration for Codec, ReduceFunction and DataConverter
+        /// </summary>
+        public IConfiguration Configuration { get; private set; }
     }
 }

http://git-wip-us.apache.org/repos/asf/incubator-reef/blob/8b7189bd/lang/cs/Org.Apache.REEF.Network/Group/Operators/Impl/ReduceOperatorSpec.cs
----------------------------------------------------------------------
diff --git a/lang/cs/Org.Apache.REEF.Network/Group/Operators/Impl/ReduceOperatorSpec.cs b/lang/cs/Org.Apache.REEF.Network/Group/Operators/Impl/ReduceOperatorSpec.cs
index 016455f..5383b7d 100644
--- a/lang/cs/Org.Apache.REEF.Network/Group/Operators/Impl/ReduceOperatorSpec.cs
+++ b/lang/cs/Org.Apache.REEF.Network/Group/Operators/Impl/ReduceOperatorSpec.cs
@@ -29,6 +29,7 @@ namespace Org.Apache.REEF.Network.Group.Operators.Impl
     /// <summary>
     /// The specification used to define Reduce Group Communication Operators.
     /// </summary>
+    /// TODO[REEF-842] Act on the obsoletes
     public class ReduceOperatorSpec : IOperatorSpec
     {
         /// <summary>
@@ -41,7 +42,7 @@ namespace Org.Apache.REEF.Network.Group.Operators.Impl
             params IConfiguration[] configurations)
         {
             ReceiverId = receiverId;
-            Configiration = Configurations.Merge(configurations);
+            Configuration = Configurations.Merge(configurations);
         }
 
         /// <summary>
@@ -53,6 +54,15 @@ namespace Org.Apache.REEF.Network.Group.Operators.Impl
         /// <summary>
         /// Returns the Configuration for Codec, ReduceFunction and DataConverter
         /// </summary>
-        public IConfiguration Configiration { get; private set; }
+        [Obsolete("Deprecated in 0.14, please use Configuration instead.")]
+        public IConfiguration Configiration {
+            get { return Configuration; }
+            private set { Configuration = value; }
+        }
+
+        /// <summary>
+        /// Returns the Configuration for Codec, ReduceFunction and DataConverter
+        /// </summary>
+        public IConfiguration Configuration { get; private set; }
     }
 }

http://git-wip-us.apache.org/repos/asf/incubator-reef/blob/8b7189bd/lang/cs/Org.Apache.REEF.Network/Group/Operators/Impl/ScatterOperatorSpec.cs
----------------------------------------------------------------------
diff --git a/lang/cs/Org.Apache.REEF.Network/Group/Operators/Impl/ScatterOperatorSpec.cs b/lang/cs/Org.Apache.REEF.Network/Group/Operators/Impl/ScatterOperatorSpec.cs
index 4c74483..f2eb94e 100644
--- a/lang/cs/Org.Apache.REEF.Network/Group/Operators/Impl/ScatterOperatorSpec.cs
+++ b/lang/cs/Org.Apache.REEF.Network/Group/Operators/Impl/ScatterOperatorSpec.cs
@@ -17,6 +17,7 @@
  * under the License.
  */
 
+using System;
 using Org.Apache.REEF.Tang.Implementations.Configuration;
 using Org.Apache.REEF.Tang.Interface;
 
@@ -25,6 +26,7 @@ namespace Org.Apache.REEF.Network.Group.Operators.Impl
     /// <summary>
     /// The specification used to define Scatter Group Communication Operators.
     /// </summary>
+    /// TODO[REEF-842] Act on the obsoletes
     public class ScatterOperatorSpec : IOperatorSpec
     {
         /// <summary>
@@ -35,7 +37,7 @@ namespace Org.Apache.REEF.Network.Group.Operators.Impl
         public ScatterOperatorSpec(string senderId, params IConfiguration[] configurations)
         {
             SenderId = senderId;
-            Configiration = Configurations.Merge(configurations);
+            Configuration = Configurations.Merge(configurations);
         }
 
         /// <summary>
@@ -47,6 +49,16 @@ namespace Org.Apache.REEF.Network.Group.Operators.Impl
         /// <summary>
         /// Returns the Configuration for Codec, ReduceFunction and DataConverter
         /// </summary>
-        public IConfiguration Configiration { get; private set; }
+        [Obsolete("Deprecated in 0.14, please use Configuration instead.")]
+        public IConfiguration Configiration
+        {
+            get { return Configuration; }
+            private set { Configuration = value; }
+        }
+
+        /// <summary>
+        /// Returns the Configuration for Codec, ReduceFunction and DataConverter
+        /// </summary>
+        public IConfiguration Configuration { get; private set; }
     }
 }

http://git-wip-us.apache.org/repos/asf/incubator-reef/blob/8b7189bd/lang/cs/Org.Apache.REEF.Network/Group/Task/ICommunicationGroupClientInternal.cs
----------------------------------------------------------------------
diff --git a/lang/cs/Org.Apache.REEF.Network/Group/Task/ICommunicationGroupClientInternal.cs b/lang/cs/Org.Apache.REEF.Network/Group/Task/ICommunicationGroupClientInternal.cs
index e112254..f2b3681 100644
--- a/lang/cs/Org.Apache.REEF.Network/Group/Task/ICommunicationGroupClientInternal.cs
+++ b/lang/cs/Org.Apache.REEF.Network/Group/Task/ICommunicationGroupClientInternal.cs
@@ -22,7 +22,7 @@ namespace Org.Apache.REEF.Network.Group.Task
     internal interface ICommunicationGroupClientInternal : ICommunicationGroupClient
     {
         /// <summary>
-        /// Call each Operator to easure all the nodes in the topology group has been registered
+        /// Call each Operator to ensure all the nodes in the topology group has been registered
         /// </summary>
         void WaitingForRegistration();
     }

http://git-wip-us.apache.org/repos/asf/incubator-reef/blob/8b7189bd/lang/cs/Org.Apache.REEF.Network/Group/Task/Impl/CommunicationGroupClient.cs
----------------------------------------------------------------------
diff --git a/lang/cs/Org.Apache.REEF.Network/Group/Task/Impl/CommunicationGroupClient.cs b/lang/cs/Org.Apache.REEF.Network/Group/Task/Impl/CommunicationGroupClient.cs
index cf3e559..a5fa1da 100644
--- a/lang/cs/Org.Apache.REEF.Network/Group/Task/Impl/CommunicationGroupClient.cs
+++ b/lang/cs/Org.Apache.REEF.Network/Group/Task/Impl/CommunicationGroupClient.cs
@@ -178,7 +178,7 @@ namespace Org.Apache.REEF.Network.Group.Task.Impl
         }
 
         /// <summary>
-        /// Call each Operator to easure all the nodes in the topology group has been registered
+        /// Call each Operator to ensure all the nodes in the topology group has been registered
         /// </summary>
         void ICommunicationGroupClientInternal.WaitingForRegistration()
         {

http://git-wip-us.apache.org/repos/asf/incubator-reef/blob/8b7189bd/lang/cs/Org.Apache.REEF.Network/Group/Topology/FlatTopology.cs
----------------------------------------------------------------------
diff --git a/lang/cs/Org.Apache.REEF.Network/Group/Topology/FlatTopology.cs b/lang/cs/Org.Apache.REEF.Network/Group/Topology/FlatTopology.cs
index b182a39..d12af8f 100644
--- a/lang/cs/Org.Apache.REEF.Network/Group/Topology/FlatTopology.cs
+++ b/lang/cs/Org.Apache.REEF.Network/Group/Topology/FlatTopology.cs
@@ -149,7 +149,7 @@ namespace Org.Apache.REEF.Network.Group.Topology
                 throw new NotSupportedException("Spec type not supported");
             }
 
-            return Configurations.Merge(confBuilder.Build(), OperatorSpec.Configiration);
+            return Configurations.Merge(confBuilder.Build(), OperatorSpec.Configuration);
         }
 
         private static void SetMessageType(Type operatorType, ICsConfigurationBuilder confBuilder)

http://git-wip-us.apache.org/repos/asf/incubator-reef/blob/8b7189bd/lang/cs/Org.Apache.REEF.Network/Group/Topology/TreeTopology.cs
----------------------------------------------------------------------
diff --git a/lang/cs/Org.Apache.REEF.Network/Group/Topology/TreeTopology.cs b/lang/cs/Org.Apache.REEF.Network/Group/Topology/TreeTopology.cs
index 3e76b64..56ab033 100644
--- a/lang/cs/Org.Apache.REEF.Network/Group/Topology/TreeTopology.cs
+++ b/lang/cs/Org.Apache.REEF.Network/Group/Topology/TreeTopology.cs
@@ -52,7 +52,7 @@ namespace Org.Apache.REEF.Network.Group.Topology
         /// <param name="rootId">The root Task identifier</param>
         /// <param name="driverId">The driver identifier</param>
         /// <param name="operatorSpec">The operator specification</param>
-        /// <param name="fanOut">The number of chldren for a tree node</param>
+        /// <param name="fanOut">The number of children for a tree node</param>
         public TreeTopology(
             string operatorName, 
             string groupName, 
@@ -164,7 +164,7 @@ namespace Org.Apache.REEF.Network.Group.Topology
                 throw new NotSupportedException("Spec type not supported");
             }
 
-            return Configurations.Merge(confBuilder.Build(), OperatorSpec.Configiration);
+            return Configurations.Merge(confBuilder.Build(), OperatorSpec.Configuration);
         }
 
         public void AddTask(string taskId)

http://git-wip-us.apache.org/repos/asf/incubator-reef/blob/8b7189bd/lang/cs/Org.Apache.REEF.Network/Naming/NameClient.cs
----------------------------------------------------------------------
diff --git a/lang/cs/Org.Apache.REEF.Network/Naming/NameClient.cs b/lang/cs/Org.Apache.REEF.Network/Naming/NameClient.cs
index 27351be..226e145 100644
--- a/lang/cs/Org.Apache.REEF.Network/Naming/NameClient.cs
+++ b/lang/cs/Org.Apache.REEF.Network/Naming/NameClient.cs
@@ -184,7 +184,7 @@ namespace Org.Apache.REEF.Network.Naming
         /// Do not use cache
         /// </summary>
         /// <param name="ids">The list of identifiers to look up</param>
-        /// <returns>The list of NameAssignments representing a pair of identifer
+        /// <returns>The list of NameAssignments representing a pair of identifier
         /// and mapped IPEndpoint for that identifier.  If any of the requested identifiers
         /// are not registered with the NameService, their corresponding NameAssignment
         /// IPEndpoint value will be null.</returns>

http://git-wip-us.apache.org/repos/asf/incubator-reef/blob/8b7189bd/lang/cs/Org.Apache.REEF.Network/Naming/NameLookupClient.cs
----------------------------------------------------------------------
diff --git a/lang/cs/Org.Apache.REEF.Network/Naming/NameLookupClient.cs b/lang/cs/Org.Apache.REEF.Network/Naming/NameLookupClient.cs
index 013aec8..211967f 100644
--- a/lang/cs/Org.Apache.REEF.Network/Naming/NameLookupClient.cs
+++ b/lang/cs/Org.Apache.REEF.Network/Naming/NameLookupClient.cs
@@ -60,7 +60,7 @@ namespace Org.Apache.REEF.Network.Naming
         /// </summary>
         /// <param name="id">The id for the IPEndPoint</param>
         /// <param name="token">The cancellation token used for timeout</param>
-        /// <returns>The registered IPEndpoint, or null if the identifer has not 
+        /// <returns>The registered IPEndpoint, or null if the identifier has not 
         /// been registered with the NameServer or if the operation times out.</returns>
         public IPEndPoint Lookup(string id, CancellationToken token)
         {

http://git-wip-us.apache.org/repos/asf/incubator-reef/blob/8b7189bd/lang/cs/Org.Apache.REEF.Network/Naming/NameRegisterClient.cs
----------------------------------------------------------------------
diff --git a/lang/cs/Org.Apache.REEF.Network/Naming/NameRegisterClient.cs b/lang/cs/Org.Apache.REEF.Network/Naming/NameRegisterClient.cs
index 95de43c..e06b587 100644
--- a/lang/cs/Org.Apache.REEF.Network/Naming/NameRegisterClient.cs
+++ b/lang/cs/Org.Apache.REEF.Network/Naming/NameRegisterClient.cs
@@ -58,7 +58,7 @@ namespace Org.Apache.REEF.Network.Naming
         /// <summary>
         /// Synchronously unregisters the identifier with the NameServer.
         /// </summary>
-        /// <param name="id">The identifer to unregister</param>
+        /// <param name="id">The identifier to unregister</param>
         public void Unregister(string id)
         {
             _client.Send(new NamingUnregisterRequest(id));
diff --git a/lang/cs/Org.Apache.REEF.Driver/Constants.cs b/lang/cs/Org.Apache.REEF.Driver/Constants.cs
index e00f5f0..ef8b87d 100644
--- a/lang/cs/Org.Apache.REEF.Driver/Constants.cs
+++ b/lang/cs/Org.Apache.REEF.Driver/Constants.cs
@@ -22,6 +22,7 @@ using System.Collections.Generic;
 
 namespace Org.Apache.REEF.Driver
 {
+    // TODO[REEF-842] Act on the obsoletes
     public class Constants
     {
         /// <summary>
@@ -32,10 +33,16 @@ namespace Org.Apache.REEF.Driver
         /// <summary>
         /// The class hierarchy file from .NET.
         /// </summary>
+        [Obsolete("Deprecated in 0.14, please use ClassHierarchyBin instead.")]
         public const string ClassHierarachyBin = "clrClassHierarchy.bin";
 
         /// <summary>
-        /// The file containing user supplied libaries.
+        /// The class hierarchy file from .NET.
+        /// </summary>
+        public const string ClassHierarchyBin = "clrClassHierarchy.bin";
+
+        /// <summary>
+        /// The file containing user supplied libraries.
         /// </summary>
         public const string GlobalUserSuppliedJavaLibraries = "userSuppliedGlobalLibraries.txt";
 

http://git-wip-us.apache.org/repos/asf/incubator-reef/blob/8b7189bd/lang/cs/Org.Apache.REEF.Driver/Defaults/DefaultClientCloseWithMessageHandler.cs
----------------------------------------------------------------------